==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebCardHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardHeaderDescription } from "./WebCardHeaderDescription";
/**
 * @hidden
 */
var WebCardHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCardHeaderDescriptionMetadata, _super);
    function WebCardHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardHeaderDescriptionMetadata.b = function (a) {
        if (WebCardHeaderDescriptionMetadata.a == null) {
            WebCardHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardHeaderDescriptionMetadata.c(WebCardHeaderDescriptionMetadata.a);
        }
        if (a.k(WebCardHeaderDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebCardHeaderDescriptionMetadata.a);
    };
    WebCardHeaderDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CardHeader");
        a.item("__tagNameWC", "String:igc-card-header");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebCardHeaderDescriptionMetadata.d = function (a) {
        WebCardHeaderDescriptionMetadata.b(a);
        a.ad("WebCardHeader", function () { return new WebCardHeaderDescription(); });
        a.ac("WebCardHeader", WebCardHeaderDescriptionMetadata.a);
    };
    WebCardHeaderDescriptionMetadata.$t = markType(WebCardHeaderDescriptionMetadata, 'WebCardHeaderDescriptionMetadata');
    WebCardHeaderDescriptionMetadata.a = null;
    return WebCardHeaderDescriptionMetadata;
}(Base));
export { WebCardHeaderDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebCardHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardHeaderDescription } from "./WebCardHeaderDescription";
/**
 * @hidden
 */
var WebCardHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCardHeaderDescriptionMetadata, _super);
    function WebCardHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardHeaderDescriptionMetadata.b = function (a) {
        if (WebCardHeaderDescriptionMetadata.a == null) {
            WebCardHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardHeaderDescriptionMetadata.c(WebCardHeaderDescriptionMetadata.a);
        }
        if (a.k(WebCardHeaderDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebCardHeaderDescriptionMetadata.a);
    };
    WebCardHeaderDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CardHeader");
        a.item("__tagNameWC", "String:igc-card-header");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebCardHeaderDescriptionMetadata.d = function (a) {
        WebCardHeaderDescriptionMetadata.b(a);
        a.ae("WebCardHeader", function () { return new WebCardHeaderDescription(); });
        a.ad("WebCardHeader", WebCardHeaderDescriptionMetadata.a);
    };
    WebCardHeaderDescriptionMetadata.$t = markType(WebCardHeaderDescriptionMetadata, 'WebCardHeaderDescriptionMetadata');
    WebCardHeaderDescriptionMetadata.a = null;
    return WebCardHeaderDescriptionMetadata;
}(Base));
export { WebCardHeaderDescriptionMetadata };
